"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var TestHelpers_1 = require("../parser/__tests__/TestHelpers");
var ParagraphSplitter_1 = require("../parser/ParagraphSplitter");
var index_1 = require("../index");
test('01 Basic paragraph splitting', function () {
    TestHelpers_1.TestHelpers.parseAndMatchDocCommentSnapshot([
        '/**',
        ' *    ',
        ' * This is the',
        ' * first paragraph.',
        ' *   \t   ',
        ' *  ',
        ' *   \t   ',
        ' * This is the second paragraph.',
        ' *',
        ' * This is the third paragraph.',
        ' *',
        ' *   ',
        ' */'
    ].join('\n'));
});
test('02 Degenerate paragraph', function () {
    TestHelpers_1.TestHelpers.parseAndMatchDocCommentSnapshot([
        '/** line 1',
        ' * line 2',
        '',
        ' *   @public line 3*/'
    ].join('\n'));
});
test('03 Degenerate manually constructed nodes', function () {
    var docSection = new index_1.DocSection({});
    var docParagraph = new index_1.DocParagraph({});
    docParagraph.appendNodes([
        new index_1.DocPlainText({ text: '  para 1 ' }),
        new index_1.DocSoftBreak({}),
        new index_1.DocPlainText({ text: '   ' }),
        new index_1.DocSoftBreak({}),
        new index_1.DocPlainText({ text: ' \t  ' }),
        new index_1.DocPlainText({ text: '   ' }),
        new index_1.DocBlockTag({ tagName: '@public' }),
        new index_1.DocPlainText({ text: '  para 2 ' }),
        new index_1.DocSoftBreak({}),
        new index_1.DocSoftBreak({}),
        new index_1.DocPlainText({ text: '  para 3  ' })
    ]);
    docSection.appendNode(docParagraph);
    // Currently we do not discard empty paragraphs
    docSection.appendNode(new index_1.DocParagraph({}));
    ParagraphSplitter_1.ParagraphSplitter.splitParagraphsForSection(docSection);
    expect(TestHelpers_1.TestHelpers.getDocNodeSnapshot(docSection)).toMatchSnapshot();
});
//# sourceMappingURL=ParagraphSplitter.test.js.map