"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var index_1 = require("../index");
var TestHelpers_1 = require("../parser/__tests__/TestHelpers");
test('01 Simple @beta and @internal extraction', function () {
    var parserContext = TestHelpers_1.TestHelpers.parseAndMatchDocCommentSnapshot([
        '/**',
        ' * START @beta',
        ' * @unknownTag',
        ' * @internal @internal END',
        ' */'
    ].join('\n'));
    var docComment = parserContext.docComment;
    var modifierTagSet = docComment.modifierTagSet;
    expect(modifierTagSet.isAlpha()).toEqual(false);
    expect(modifierTagSet.isBeta()).toEqual(true);
    expect(modifierTagSet.isInternal()).toEqual(true);
});
test('02 A basic TSDoc comment with common components', function () {
    var configuration = new index_1.TSDocParserConfiguration();
    configuration.addTagDefinitions([
        new index_1.TSDocTagDefinition({
            tagName: '@customBlock',
            syntaxKind: index_1.TSDocTagSyntaxKind.BlockTag
        }),
        new index_1.TSDocTagDefinition({
            tagName: '@customModifier',
            syntaxKind: index_1.TSDocTagSyntaxKind.ModifierTag
        })
    ]);
    var parserContext = TestHelpers_1.TestHelpers.parseAndMatchDocCommentSnapshot([
        '/**',
        ' * Returns the average of two numbers.',
        ' *',
        ' * @remarks',
        ' * This method is part of the {@link core-library#Statistics | Statistics subsystem}.',
        ' *',
        ' * @customBlock',
        ' * This is a custom block containing an @undefinedBlockTag',
        ' *',
        ' * @param x - The first input number',
        ' * @param y - The second input number',
        ' * @returns The arithmetic mean of `x` and `y`',
        ' *',
        ' * @beta @customModifier',
        ' */'
    ].join('\n'), configuration);
    var docComment = parserContext.docComment;
    expect(docComment.modifierTagSet.hasTagName('@customModifier')).toEqual(true);
});
test('03 Jumbled order', function () {
    var configuration = new index_1.TSDocParserConfiguration();
    configuration.addTagDefinitions([
        new index_1.TSDocTagDefinition({
            tagName: '@customBlock',
            syntaxKind: index_1.TSDocTagSyntaxKind.BlockTag
        }),
        new index_1.TSDocTagDefinition({
            tagName: '@customModifier',
            syntaxKind: index_1.TSDocTagSyntaxKind.ModifierTag
        })
    ]);
    var parserContext = TestHelpers_1.TestHelpers.parseAndMatchDocCommentSnapshot([
        '/**',
        ' * Returns the average of two numbers. @remarks This method is part of the',
        ' * {@link core-library#Statistics | Statistics subsystem}.',
        ' * @beta @customModifier',
        ' * @returns The arithmetic mean of `x` and `y`',
        ' * @param x - The first input number @param y - The second input number',
        ' * @customBlock',
        ' * This is a custom block containing an @undefinedBlockTag',
        ' */'
    ].join('\n'), configuration);
    var docComment = parserContext.docComment;
    expect(docComment.modifierTagSet.hasTagName('@customModifier')).toEqual(true);
});
test('03 Incomplete @param blocks', function () {
    TestHelpers_1.TestHelpers.parseAndMatchDocCommentSnapshot([
        '/**',
        ' * @param - The first input number',
        ' * @param y The second input number',
        ' * @returns The arithmetic mean of `x` and `y`',
        ' */'
    ].join('\n'));
});
test('04 typeParam blocks', function () {
    TestHelpers_1.TestHelpers.parseAndMatchDocCommentSnapshot([
        '/**',
        ' * Constructs a map from a JavaScript object',
        ' *',
        ' * @typeParam K - The generic type parameter indicating the key type',
        ' * @param jsonObject - The input object',
        ' * @typeParam V - The generic type parameter indicating the value type',
        ' * @returns The map',
        ' */'
    ].join('\n'));
});
//# sourceMappingURL=ParsingBasics.test.js.map