import { DocNodeKind, IDocNodeParameters, DocNode } from './DocNode';
import { Excerpt } from '../parser/Excerpt';
/**
 * Constructor parameters for {@link DocCodeFence}.
 */
export interface IDocCodeFenceParameters extends IDocNodeParameters {
    openingDelimiterExcerpt?: Excerpt;
    languageExcerpt?: Excerpt;
    language?: string | 'ts' | '';
    codeExcerpt?: Excerpt;
    code: string;
    closingDelimiterExcerpt?: Excerpt;
}
/**
 * Represents CommonMark-style code fence, i.e. a block of program code that
 * starts and ends with a line comprised of three backticks.  The opening delimiter
 * can also specify a language for a syntax highlighter.
 */
export declare class DocCodeFence extends DocNode {
    /** {@inheritDoc} */
    readonly kind: DocNodeKind;
    private _openingDelimiterParticle;
    private _languageParticle;
    private _codeParticle;
    private _closingDelimiterParticle;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocCodeFenceParameters);
    /**
     * A name that can optionally be included after the opening code fence delimiter,
     * on the same line as the three backticks.  This name indicates the programming language
     * for the code, which a syntax highlighter may use to style the code block.
     *
     * @remarks
     * The TSDoc standard requires that the language "ts" should be interpreted to mean TypeScript.
     * Other languages names may be supported, but this is implementation dependent.
     *
     * CommonMark refers to this field as the "info string".
     *
     * @privateRemarks
     * Examples of language strings supported by GitHub flavored markdown:
     * https://raw.githubusercontent.com/github/linguist/master/lib/linguist/languages.yml
     */
    readonly language: string | 'ts' | '';
    /**
     * The text that should be rendered as code.
     */
    readonly code: string;
    /** @override */
    updateParameters(parameters: IDocCodeFenceParameters): void;
    /**
     * {@inheritDoc}
     * @override
     */
    getChildNodes(): ReadonlyArray<DocNode>;
}
