"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var DocNode_1 = require("./DocNode");
var DocParticle_1 = require("./DocParticle");
/**
 * Represents CommonMark-style code fence, i.e. a block of program code that
 * starts and ends with a line comprised of three backticks.  The opening delimiter
 * can also specify a language for a syntax highlighter.
 */
var DocCodeFence = /** @class */ (function (_super) {
    __extends(DocCodeFence, _super);
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    function DocCodeFence(parameters) {
        var _this = _super.call(this, parameters) || this;
        /** {@inheritDoc} */
        _this.kind = "CodeFence" /* CodeFence */;
        return _this;
    }
    Object.defineProperty(DocCodeFence.prototype, "language", {
        /**
         * A name that can optionally be included after the opening code fence delimiter,
         * on the same line as the three backticks.  This name indicates the programming language
         * for the code, which a syntax highlighter may use to style the code block.
         *
         * @remarks
         * The TSDoc standard requires that the language "ts" should be interpreted to mean TypeScript.
         * Other languages names may be supported, but this is implementation dependent.
         *
         * CommonMark refers to this field as the "info string".
         *
         * @privateRemarks
         * Examples of language strings supported by GitHub flavored markdown:
         * https://raw.githubusercontent.com/github/linguist/master/lib/linguist/languages.yml
         */
        get: function () {
            return this._languageParticle.content;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocCodeFence.prototype, "code", {
        /**
         * The text that should be rendered as code.
         */
        get: function () {
            return this._codeParticle.content;
        },
        enumerable: true,
        configurable: true
    });
    /** @override */
    DocCodeFence.prototype.updateParameters = function (parameters) {
        _super.prototype.updateParameters.call(this, parameters);
        this._openingDelimiterParticle = new DocParticle_1.DocParticle({
            particleId: 'openingDelimiter',
            excerpt: parameters.openingDelimiterExcerpt,
            content: '```'
        });
        this._languageParticle = new DocParticle_1.DocParticle({
            particleId: 'language',
            excerpt: parameters.languageExcerpt,
            content: parameters.language || ''
        });
        this._codeParticle = new DocParticle_1.DocParticle({
            particleId: 'code',
            excerpt: parameters.codeExcerpt,
            content: parameters.code
        });
        this._closingDelimiterParticle = new DocParticle_1.DocParticle({
            particleId: 'closingDelimiter',
            excerpt: parameters.closingDelimiterExcerpt,
            content: '```'
        });
    };
    /**
     * {@inheritDoc}
     * @override
     */
    DocCodeFence.prototype.getChildNodes = function () {
        return [
            this._openingDelimiterParticle,
            this._languageParticle,
            this._codeParticle,
            this._closingDelimiterParticle
        ];
    };
    return DocCodeFence;
}(DocNode_1.DocNode));
exports.DocCodeFence = DocCodeFence;
//# sourceMappingURL=DocCodeFence.js.map