import { DocNodeKind } from './DocNode';
import { DocNodeLeaf, IDocNodeLeafParameters } from './DocNodeLeaf';
/**
 * Constructor parameters for {@link DocEscapedText}.
 */
export interface IDocEscapedTextParameters extends IDocNodeLeafParameters {
    escapeStyle: EscapeStyle;
    text: string;
}
/**
 * The style of escaping to be used with DocEscapedText.
 */
export declare enum EscapeStyle {
    /**
     * Use a backslash symbol to escape the character.
     */
    CommonMarkBackslash = 0
}
/**
 * Represents a text character that should be escaped as a TSDoc symbol.
 * @remarks
 * Note that renders will normally apply appropriate escaping when rendering
 * DocPlainText in a format such as HTML or TSDoc.  The DocEscapedText node
 * forces a specific escaping that may not be the default.
 */
export declare class DocEscapedText extends DocNodeLeaf {
    /** {@inheritDoc} */
    readonly kind: DocNodeKind;
    private _escapeStyle;
    private _text;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocEscapedTextParameters);
    /**
     * The style of escaping to be performed.
     */
    readonly escapeStyle: EscapeStyle;
    /**
     * The text content to be escaped.
     */
    readonly text: string;
    /** @override */
    updateParameters(parameters: IDocEscapedTextParameters): void;
}
