import { DocNode, DocNodeKind, IDocNodeParameters } from './DocNode';
import { Excerpt } from '../parser/Excerpt';
/**
 * Constructor parameters for {@link DocHtmlAttribute}.
 */
export interface IDocHtmlAttributeParameters extends IDocNodeParameters {
    attributeNameExcerpt?: Excerpt;
    attributeName: string;
    spacingAfterAttributeName: string | undefined;
    equalsExcerpt?: Excerpt;
    spacingAfterEquals: string | undefined;
    attributeValueExcerpt?: Excerpt;
    attributeValue: string;
    spacingAfterAttributeValue: string | undefined;
}
/**
 * Represents an HTML attribute inside a DocHtmlStartTag or DocHtmlEndTag.
 *
 * Example: `href="#"` inside `<a href="#" />`
 */
export declare class DocHtmlAttribute extends DocNode {
    /** {@inheritDoc} */
    readonly kind: DocNodeKind;
    private _attributeNameParticle;
    private _equalsParticle;
    private _attributeValueParticle;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocHtmlAttributeParameters);
    /**
     * The HTML attribute name.
     */
    readonly attributeName: string;
    /**
     * Explicit whitespace that a renderer should insert after the HTML attribute name.
     * If undefined, then the renderer can use a formatting rule to generate appropriate spacing.
     */
    readonly spacingAfterAttributeName: string | undefined;
    /**
     * Explicit whitespace that a renderer should insert after the "=".
     * If undefined, then the renderer can use a formatting rule to generate appropriate spacing.
     */
    readonly spacingAfterEquals: string | undefined;
    /**
     * The HTML attribute value.
     */
    readonly attributeValue: string;
    /**
     * Explicit whitespace that a renderer should insert after the HTML attribute name.
     * If undefined, then the renderer can use a formatting rule to generate appropriate spacing.
     */
    readonly spacingAfterAttributeValue: string | undefined;
    /** @override */
    updateParameters(parameters: IDocHtmlAttributeParameters): void;
    /**
     * {@inheritDoc}
     * @override
     */
    getChildNodes(): ReadonlyArray<DocNode>;
}
