import { DocNodeKind, IDocNodeParameters, DocNode } from './DocNode';
import { DocParticle } from './DocParticle';
import { Excerpt } from '../parser/Excerpt';
/**
 * Constructor parameters for {@link DocInlineTag}.
 */
export interface IDocInlineTagParameters extends IDocNodeParameters {
    openingDelimiterExcerpt?: Excerpt;
    tagNameExcerpt?: Excerpt;
    tagName: string;
    tagContentExcerpt?: Excerpt;
    tagContent: string;
    closingDelimiterExcerpt?: Excerpt;
}
/**
 * Represents a TSDoc inline tag such as `{@inheritDoc}` or `{@link}`.
 */
export declare class DocInlineTag extends DocNode {
    /** {@inheritDoc} */
    readonly kind: DocNodeKind;
    private _openingDelimiterParticle;
    private _tagNameParticle;
    private _tagContentParticle;
    private _closingDelimiterParticle;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocInlineTagParameters);
    /**
     * The TSDoc tag name.
     * For example, if the inline tag is `{@link Guid.toString | the toString() method}`
     * then the tag name would be `@link`.
     */
    readonly tagName: string;
    /**
     * The tag content.
     * For example, if the inline tag is `{@link Guid.toString | the toString() method}`
     * then the tag content would be `Guid.toString | the toString() method`.
     */
    readonly tagContent: string;
    /** @override */
    updateParameters(parameters: IDocInlineTagParameters): void;
    /**
     * {@inheritDoc}
     * @override @sealed
     */
    getChildNodes(): ReadonlyArray<DocNode>;
    /**
     * Allows child classes to replace the tagContentParticle with a more detailed
     * set of nodes.
     * @virtual
     */
    protected getChildNodesForContent(): ReadonlyArray<DocNode>;
    protected readonly tagContentParticle: DocParticle;
}
