import { DocNodeKind, DocNode } from './DocNode';
import { DocInlineTag, IDocInlineTagParameters } from './DocInlineTag';
import { DocDeclarationReference } from './DocDeclarationReference';
import { Excerpt } from '../parser/Excerpt';
/**
 * Constructor parameters for {@link DocLinkTag}.
 */
export interface IDocLinkTagParameters extends IDocInlineTagParameters {
    codeDestination?: DocDeclarationReference;
    urlDestinationExcerpt?: Excerpt;
    urlDestination?: string;
    pipeExcerpt?: Excerpt;
    linkTextExcerpt?: Excerpt;
    linkText?: string;
}
/**
 * Represents an `{@link}` tag.
 */
export declare class DocLinkTag extends DocInlineTag {
    /** {@inheritDoc} */
    readonly kind: DocNodeKind;
    private _codeDestination;
    private _urlDestinationParticle;
    private _pipeParticle;
    private _linkTextParticle;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocLinkTagParameters);
    /**
     * If the link tag refers to a declaration, this returns the declaration reference object;
     * otherwise this property is undefined.
     * @remarks
     * Either the `codeDestination` or the `urlDestination` property will be defined, but never both.
     */
    readonly codeDestination: DocDeclarationReference | undefined;
    /**
     * If the link tag was an ordinary URI, this returns the URL string;
     * otherwise this property is undefined.
     * @remarks
     * Either the `codeDestination` or the `urlDestination` property will be defined, but never both.
     */
    readonly urlDestination: string | undefined;
    /**
     * An optional text string that is the hyperlink text.  If omitted, the documentation
     * renderer will use a default string based on the link itself (e.g. the URL text
     * or the declaration identifier).
     */
    readonly linkText: string | undefined;
    /** @override */
    updateParameters(parameters: IDocLinkTagParameters): void;
    /**
     * {@inheritDoc}
     * @override
     */
    protected getChildNodesForContent(): ReadonlyArray<DocNode>;
}
