"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var DocNode_1 = require("./DocNode");
var DocInlineTag_1 = require("./DocInlineTag");
var DocParticle_1 = require("./DocParticle");
/**
 * Represents an `{@link}` tag.
 */
var DocLinkTag = /** @class */ (function (_super) {
    __extends(DocLinkTag, _super);
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    function DocLinkTag(parameters) {
        var _this = _super.call(this, parameters) || this;
        /** {@inheritDoc} */
        _this.kind = "LinkTag" /* LinkTag */;
        return _this;
    }
    Object.defineProperty(DocLinkTag.prototype, "codeDestination", {
        /**
         * If the link tag refers to a declaration, this returns the declaration reference object;
         * otherwise this property is undefined.
         * @remarks
         * Either the `codeDestination` or the `urlDestination` property will be defined, but never both.
         */
        get: function () {
            return this._codeDestination;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocLinkTag.prototype, "urlDestination", {
        /**
         * If the link tag was an ordinary URI, this returns the URL string;
         * otherwise this property is undefined.
         * @remarks
         * Either the `codeDestination` or the `urlDestination` property will be defined, but never both.
         */
        get: function () {
            return this._urlDestinationParticle ? this._urlDestinationParticle.content : undefined;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocLinkTag.prototype, "linkText", {
        /**
         * An optional text string that is the hyperlink text.  If omitted, the documentation
         * renderer will use a default string based on the link itself (e.g. the URL text
         * or the declaration identifier).
         */
        get: function () {
            if (this._linkTextParticle) {
                return this._linkTextParticle.content;
            }
            else {
                return undefined;
            }
        },
        enumerable: true,
        configurable: true
    });
    /** @override */
    DocLinkTag.prototype.updateParameters = function (parameters) {
        if (parameters.tagName.toUpperCase() !== '@LINK') {
            throw new Error('DocLinkTag requires the tag name to be "{@link}"');
        }
        if (parameters.codeDestination !== undefined) {
            if (parameters.urlDestination !== undefined) {
                throw new Error('Either the codeLink or the documentLink may be specified, but not both');
            }
        }
        if (parameters.tagContentExcerpt !== undefined) {
            if (parameters.codeDestination || parameters.urlDestinationExcerpt || parameters.linkTextExcerpt) {
                // This would violate the TokenCoverageChecker properties
                throw new Error('The input cannot be associated with tagContentExcerpt and also the detail excerpts');
            }
        }
        _super.prototype.updateParameters.call(this, parameters);
        this._codeDestination = undefined;
        this._urlDestinationParticle = undefined;
        this._pipeParticle = undefined;
        this._linkTextParticle = undefined;
        if (parameters.codeDestination) {
            this._codeDestination = parameters.codeDestination;
        }
        else if (parameters.urlDestination !== undefined) {
            this._urlDestinationParticle = new DocParticle_1.DocParticle({
                particleId: 'urlDestination',
                excerpt: parameters.urlDestinationExcerpt,
                content: parameters.urlDestination
            });
        }
        if (parameters.linkTextExcerpt || parameters.linkText || parameters.pipeExcerpt) {
            this._pipeParticle = new DocParticle_1.DocParticle({
                particleId: 'pipe',
                excerpt: parameters.pipeExcerpt,
                content: '|'
            });
        }
        if (parameters.linkText !== undefined) {
            this._linkTextParticle = new DocParticle_1.DocParticle({
                particleId: 'linkText',
                excerpt: parameters.linkTextExcerpt,
                content: parameters.linkText
            });
        }
    };
    /**
     * {@inheritDoc}
     * @override
     */
    DocLinkTag.prototype.getChildNodesForContent = function () {
        if (this.tagContentParticle.excerpt) {
            // If the parser associated the inline tag input with the tagContentExcerpt (e.g. because
            // second stage parsing encountered an error), then fall back to the base class's representation
            return _super.prototype.getChildNodesForContent.call(this);
        }
        else {
            // Otherwise return the detailed structure
            return DocNode_1.DocNode.trimUndefinedNodes([
                this._urlDestinationParticle,
                this._codeDestination,
                this._pipeParticle,
                this._linkTextParticle
            ]);
        }
    };
    return DocLinkTag;
}(DocInlineTag_1.DocInlineTag));
exports.DocLinkTag = DocLinkTag;
//# sourceMappingURL=DocLinkTag.js.map