import { DocNodeKind, DocNode, IDocNodeParameters } from './DocNode';
import { Excerpt } from '../parser/Excerpt';
/**
 * Constructor parameters for {@link DocMemberIdentifier}.
 */
export interface IDocMemberIdentifierParameters extends IDocNodeParameters {
    leftQuoteExcerpt?: Excerpt | undefined;
    identifierExcerpt?: Excerpt | undefined;
    identifier: string;
    rightQuoteExcerpt?: Excerpt | undefined;
}
/**
 * A member identifier is part of a {@link DocMemberReference}.
 */
export declare class DocMemberIdentifier extends DocNode {
    /** {@inheritDoc} */
    readonly kind: DocNodeKind;
    private _leftQuoteParticle;
    private _identifierParticle;
    private _rightQuoteParticle;
    /**
     * Returns true if the specified string is a valid TypeScript
     * identifier.  If not, {@link DocMemberIdentifier.hasQuotes} will be
     * required.
     */
    static isValidIdentifier(identifier: string): boolean;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocMemberIdentifierParameters);
    /**
     * The identifier string without any quote encoding.
     *
     * @remarks
     * If the value is not a valid ECMAScript identifier, it will be quoted as a
     * string literal during rendering.
     */
    readonly identifier: string;
    /**
     * Returns true if the identifier will be rendered as a quoted string literal
     * instead of as a programming language identifier.  This is required if the
     * `identifier` property is not a valid ECMAScript identifier.
     */
    readonly hasQuotes: boolean;
    /** @override */
    updateParameters(parameters: IDocMemberIdentifierParameters): void;
    /**
     * {@inheritDoc}
     * @override
     */
    getChildNodes(): ReadonlyArray<DocNode>;
}
