"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var DocNode_1 = require("./DocNode");
var DocParticle_1 = require("./DocParticle");
var StringChecks_1 = require("../parser/StringChecks");
/**
 * A member identifier is part of a {@link DocMemberReference}.
 */
var DocMemberIdentifier = /** @class */ (function (_super) {
    __extends(DocMemberIdentifier, _super);
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    function DocMemberIdentifier(parameters) {
        var _this = _super.call(this, parameters) || this;
        /** {@inheritDoc} */
        _this.kind = "MemberIdentifier" /* MemberIdentifier */;
        return _this;
    }
    /**
     * Returns true if the specified string is a valid TypeScript
     * identifier.  If not, {@link DocMemberIdentifier.hasQuotes} will be
     * required.
     */
    DocMemberIdentifier.isValidIdentifier = function (identifier) {
        return !StringChecks_1.StringChecks.explainIfInvalidUnquotedIdentifier(identifier);
    };
    Object.defineProperty(DocMemberIdentifier.prototype, "identifier", {
        /**
         * The identifier string without any quote encoding.
         *
         * @remarks
         * If the value is not a valid ECMAScript identifier, it will be quoted as a
         * string literal during rendering.
         */
        get: function () {
            return this._identifierParticle.content;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocMemberIdentifier.prototype, "hasQuotes", {
        /**
         * Returns true if the identifier will be rendered as a quoted string literal
         * instead of as a programming language identifier.  This is required if the
         * `identifier` property is not a valid ECMAScript identifier.
         */
        get: function () {
            return !!this._leftQuoteParticle;
        },
        enumerable: true,
        configurable: true
    });
    /** @override */
    DocMemberIdentifier.prototype.updateParameters = function (parameters) {
        _super.prototype.updateParameters.call(this, parameters);
        this._leftQuoteParticle = undefined;
        this._identifierParticle = undefined;
        this._rightQuoteParticle = undefined;
        if (parameters.leftQuoteExcerpt || !DocMemberIdentifier.isValidIdentifier(parameters.identifier)) {
            this._leftQuoteParticle = new DocParticle_1.DocParticle({
                particleId: 'leftQuote',
                excerpt: parameters.leftQuoteExcerpt,
                content: '"'
            });
        }
        this._identifierParticle = new DocParticle_1.DocParticle({
            particleId: 'identifier',
            excerpt: parameters.identifierExcerpt,
            content: parameters.identifier
        });
        if (this._leftQuoteParticle) {
            this._rightQuoteParticle = new DocParticle_1.DocParticle({
                particleId: 'rightQuote',
                excerpt: parameters.rightQuoteExcerpt,
                content: '"'
            });
        }
    };
    /**
     * {@inheritDoc}
     * @override
     */
    DocMemberIdentifier.prototype.getChildNodes = function () {
        return DocNode_1.DocNode.trimUndefinedNodes([
            this._leftQuoteParticle,
            this._identifierParticle,
            this._rightQuoteParticle
        ]);
    };
    return DocMemberIdentifier;
}(DocNode_1.DocNode));
exports.DocMemberIdentifier = DocMemberIdentifier;
//# sourceMappingURL=DocMemberIdentifier.js.map