/**
 * Indicates the type of {@link DocNode}.
 */
export declare const enum DocNodeKind {
    Block = "Block",
    BlockTag = "BlockTag",
    CodeFence = "CodeFence",
    CodeSpan = "CodeSpan",
    Comment = "Comment",
    DeclarationReference = "DeclarationReference",
    ErrorText = "ErrorText",
    EscapedText = "EscapedText",
    HtmlAttribute = "HtmlAttribute",
    HtmlEndTag = "HtmlEndTag",
    HtmlStartTag = "HtmlStartTag",
    InheritDocTag = "InheritDocTag",
    InlineTag = "InlineTag",
    LinkTag = "LinkTag",
    MemberIdentifier = "MemberIdentifier",
    MemberReference = "MemberReference",
    MemberSelector = "MemberSelector",
    MemberSymbol = "MemberSymbol",
    Particle = "Particle",
    Paragraph = "Paragraph",
    ParamBlock = "ParamBlock",
    PlainText = "PlainText",
    Section = "Section",
    SoftBreak = "SoftBreak"
}
/**
 * Constructor parameters for {@link DocNode}.
 */
export interface IDocNodeParameters {
}
/**
 * The base class for the parser's Abstract Syntax Tree nodes.
 */
export declare abstract class DocNode {
    private static _badSpacingRegExp;
    /**
     * Indicates the kind of DocNode.
     */
    abstract readonly kind: DocNodeKind;
    /**
     * Returns the array with any undefined elements removed.
     */
    protected static trimUndefinedNodes(nodes: ReadonlyArray<DocNode | undefined>): ReadonlyArray<DocNode>;
    protected static validateSpacing(spacing: string | undefined, parameterName: string): void;
    constructor(parameters: IDocNodeParameters);
    /** @virtual */
    updateParameters(parameters: IDocNodeParameters): void;
    /**
     * Returns the list of child nodes for this node.  This is useful for visitors that want
     * to scan the tree looking for nodes of a specific type, without having to process
     * intermediary nodes.
     * @virtual
     */
    getChildNodes(): ReadonlyArray<DocNode>;
}
