"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * The base class for the parser's Abstract Syntax Tree nodes.
 */
var DocNode = /** @class */ (function () {
    function DocNode(parameters) {
        this.updateParameters(parameters);
    }
    /**
     * Returns the array with any undefined elements removed.
     */
    DocNode.trimUndefinedNodes = function (nodes) {
        return nodes.filter(function (x) { return x; });
    };
    DocNode.validateSpacing = function (spacing, parameterName) {
        if (spacing) {
            var match = DocNode._badSpacingRegExp.exec(spacing);
            if (match) {
                var badCharacter = match[0];
                throw new Error("The \"" + parameterName + "\" value contains a non-whitespace character \"" + badCharacter + "\"");
            }
        }
    };
    /** @virtual */
    DocNode.prototype.updateParameters = function (parameters) {
        // (virtual)
    };
    /**
     * Returns the list of child nodes for this node.  This is useful for visitors that want
     * to scan the tree looking for nodes of a specific type, without having to process
     * intermediary nodes.
     * @virtual
     */
    DocNode.prototype.getChildNodes = function () {
        return [];
    };
    DocNode._badSpacingRegExp = /\S/;
    return DocNode;
}());
exports.DocNode = DocNode;
//# sourceMappingURL=DocNode.js.map