"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    }
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
var DocNode_1 = require("./DocNode");
var DocNodeLeaf_1 = require("./DocNodeLeaf");
/**
 * DocParticle is used to represent additional generic nodes that are part of the
 * DocNode tree, for the purpose of providing additional Excerpt information.
 *
 * @remarks
 * For example, a DocHtmlAttribute has a "=" delimiter and a quoted text string
 * that may be interesting to highlight in an editor; however, it would be awkward
 * to expect developers to construct these nodes as part of constructing a
 * DocHtmlAttribute object.  Instead, the developer merely assigns
 * DocHtmlAttribute.attributeValue, and the particle nodes automatically appear
 * in the tree as a byproduct.  And rather than introducing lots of special-purpose
 * types (e.g. DocHtmlAttributeEqualsDelimiter or DocHtmlAttributeStringValue),
 * they are represented as generic "DocParticle" nodes.
 */
var DocParticle = /** @class */ (function (_super) {
    __extends(DocParticle, _super);
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    function DocParticle(parameters) {
        var _this = _super.call(this, parameters) || this;
        /** {@inheritDoc} */
        _this.kind = "Particle" /* Particle */;
        return _this;
    }
    Object.defineProperty(DocParticle.prototype, "particleId", {
        /**
         * A string identifier that uniquely identifies a particle among its siblings.
         * This can be used by DocNode.getChildren() visitors to determine what the particle
         * represents.
         */
        get: function () {
            return this._particleId;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocParticle.prototype, "content", {
        /**
         * The text representation of this particle, excluding any surrounding whitespace.
         */
        get: function () {
            return this._content;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DocParticle.prototype, "spacingAfterContent", {
        /**
         * Optional explicit whitespace that appears after the main content.
         * If undefined, then the renderer can use a formatting rule to generate appropriate spacing.
         */
        get: function () {
            return this._spacingAfterContent;
        },
        enumerable: true,
        configurable: true
    });
    /** @override */
    DocParticle.prototype.updateParameters = function (parameters) {
        DocNode_1.DocNode.validateSpacing(parameters.spacingAfterContent, 'spacingAfterContent');
        if (this._particleId && parameters.particleId !== this._particleId) {
            throw new Error('The particleId cannot be changed using updateParameters()');
        }
        _super.prototype.updateParameters.call(this, parameters);
        this._particleId = parameters.particleId;
        this._content = parameters.content;
        this._spacingAfterContent = parameters.spacingAfterContent;
    };
    return DocParticle;
}(DocNodeLeaf_1.DocNodeLeaf));
exports.DocParticle = DocParticle;
//# sourceMappingURL=DocParticle.js.map