import { DocNodeKind } from './DocNode';
import { DocNodeLeaf, IDocNodeLeafParameters } from './DocNodeLeaf';
/**
 * Constructor parameters for {@link DocPlainText}.
 */
export interface IDocPlainTextParameters extends IDocNodeLeafParameters {
    text: string;
}
/**
 * Represents a span of comment text that is considered by the parser
 * to contain no special symbols or meaning.
 *
 * @remarks
 * The text content must not contain newline characters.
 * Use DocSoftBreak to represent manual line splitting.
 */
export declare class DocPlainText extends DocNodeLeaf {
    private static readonly _newlineCharacterRegExp;
    /** {@inheritDoc} */
    readonly kind: DocNodeKind;
    private _text;
    /**
     * Don't call this directly.  Instead use {@link TSDocParser}
     * @internal
     */
    constructor(parameters: IDocPlainTextParameters);
    /**
     * The text content.
     */
    readonly text: string;
    /** @override */
    updateParameters(parameters: IDocPlainTextParameters): void;
}
